AuditLog

Struct AuditLog 

pub struct AuditLog { /* private fields */ }
The audit log — an append-only, tamper-evident log

Implementations

Source

impl AuditLog

pub fn new(session_id: String) -> Self

Create a new audit log with a random key

pub fn with_key(session_id: String, key: Vec<u8>) -> Self

Create a new audit log with a specific key (for testing or recovery)

pub fn set_trace_logging(&mut self, enabled: bool)

Enable or disable tracing logging

pub fn set_file_path(&mut self, path: PathBuf)

Set the file path for persistence

pub fn append( &self, event_type: AuditEventType, component: &str, description: &str, metadata: Option<Value>, ) -> Result<AuditEntry, AuditError>

Append an entry to the audit log

pub fn tool_call( &self, tool_name: &str, args: &Value, ) -> Result<AuditEntry, AuditError>

Convenience method for logging a tool call

pub fn tool_result( &self, tool_name: &str, result: &ToolResult, ) -> Result<AuditEntry, AuditError>

Convenience method for logging a tool result

pub fn policy_decision( &self, tool_name: &str, allowed: bool, reason: Option<&str>, ) -> Result<AuditEntry, AuditError>

Convenience method for logging a policy decision

pub fn approval( &self, tool_name: &str, granted: bool, reason: Option<&str>, ) -> Result<AuditEntry, AuditError>

Convenience method for logging an approval

pub fn entries(&self) -> Result<Vec<AuditEntry>, AuditError>

Get all entries

pub fn len(&self) -> Result<usize, AuditError>

Get the number of entries

pub fn is_empty(&self) -> Result<bool, AuditError>

Check if the log is empty

pub fn verify(&self) -> Result<(), AuditError>

Verify the integrity of the entire audit log

pub fn to_json(&self) -> Result<String, AuditError>

Export the audit log as JSON

pub fn to_json_lines(&self) -> Result<String, AuditError>

Export the audit log as JSON lines (one entry per line)