#[non_exhaustive]pub struct McpServerConfig {
pub name: String,
pub command: String,
pub args: Vec<String>,
pub env: HashMap<String, String>,
pub url: String,
}Expand description
Configuration for a single MCP server connection (v0.9.6)
Stability
This struct is #[non_exhaustive] — new fields may be added in minor releases.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name for this MCP server (used in logs and tool namespacing)
command: StringCommand to launch the MCP server process (stdio transport)
Either command or url must be set, but not both.
args: Vec<String>Arguments to pass to the command
env: HashMap<String, String>Environment variables to set for the MCP server process
url: StringSSE endpoint URL for SSE transport (e.g., “http://localhost:8080/sse”)
Either command or url must be set, but not both.