pub struct WasmPluginManager { /* private fields */ }Expand description
Manages a collection of loaded WASM plugins.
Implementations
Sourceimpl WasmPluginManager
impl WasmPluginManager
Sourcepub fn load(&mut self, path: &Path) -> Result<&WasmPlugin, PluginError>
pub fn load(&mut self, path: &Path) -> Result<&WasmPlugin, PluginError>
Load a plugin from a .wasm file and add it to the manager.
Sourcepub fn load_from_bytes(
&mut self,
bytes: &[u8],
) -> Result<&WasmPlugin, PluginError>
pub fn load_from_bytes( &mut self, bytes: &[u8], ) -> Result<&WasmPlugin, PluginError>
Load a plugin from bytes and add it to the manager.
Sourcepub fn get(&self, name: &str) -> Option<&WasmPlugin>
pub fn get(&self, name: &str) -> Option<&WasmPlugin>
Get a reference to a loaded plugin by name.
Sourcepub fn get_mut(&mut self, name: &str) -> Option<&mut WasmPlugin>
pub fn get_mut(&mut self, name: &str) -> Option<&mut WasmPlugin>
Get a mutable reference to a loaded plugin by name.
Sourcepub fn iter(&self) -> impl Iterator<Item = &WasmPlugin>
pub fn iter(&self) -> impl Iterator<Item = &WasmPlugin>
Iterate over all loaded plugins.
Sourcepub fn register_all(&mut self, registry: &mut ToolRegistry)
pub fn register_all(&mut self, registry: &mut ToolRegistry)
Register all tools from all plugins into a ToolRegistry.